/*
 * Copyright 2011 Apaq.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package dk.apaq.crud.vaadin;

import com.vaadin.data.Container.Sortable;
import dk.apaq.crud.Crud;
import dk.apaq.crud.HasId;
import dk.apaq.filter.sort.SortDirection;
import dk.apaq.filter.sort.Sorter;
import dk.apaq.filter.sort.SorterEntry;
import java.util.ArrayList;
import java.util.Collection;
import java.util.List;


/**
 * Crud container that implements <code>Sortable</code>. This makes it possible to easily have
 * a Vaadin table sort on columns and have the data sorted directly in the Crud backend.
 */
public class SortableCrudContainer<IDT, BT> extends CrudContainer<IDT, BT>
        implements Sortable{

    private final Crud.Filterable<IDT, BT> filterableCrud;

    public SortableCrudContainer(Crud.Filterable<IDT, BT> crud, Class beanClass) {
        super(crud, beanClass);
        this.filterableCrud = crud;
    }

    @Override
    public void sort(Object[] propertyId, boolean[] ascending) {
        List<SorterEntry> sorterEntries = new ArrayList<SorterEntry>();

        for(int i=0; i<propertyId.length; i++) {
            String id = propertyId[i].toString();
            SortDirection direction = ascending[i] ? SortDirection.Ascending : SortDirection.Descending;
            sorterEntries.add(new SorterEntry(id, direction));
        }
        setSorter(new Sorter(sorterEntries));
    }

    @Override
    public Collection<?> getSortableContainerPropertyIds() {
        return getContainerPropertyIds();
    }


}
